path <- commandArgs()[6]

##############################
prior <- function(x) {
  a <- 0.385
  b <- 0.585
  c <- (a + b) / 2
  if      (a <= x & x <= c) return(2*(x - a) / ((b - a) * (c - a)) / 2 + 1 / 2)
  else if (c <  x & x <= b) return(2*(b - x) / ((b - a) * (b - c)) / 2 + 1 / 2)
  else                      return(1 / 2)
}
like <- function(x) {
  n = 980; k = 437;
  exp(lchoose(n, k) + k * log(x) + (n-k) * log(1-x))
}
prib5 <- function(x) {
  a = 2.425; b = 2.575;
  dbeta(x, a, b)
}

y <- NULL; z <- NULL; w <- NULL;
S <- seq(0, 1, 0.001)
for (i in S) {
  y <- append(y, prior(i))
  z <- append(z, like(i))
  w <- append(w, prib5(i))
}
y<-y/sum(y)
z<-z/sum(z)
w<-w/sum(w)

##############################
postscript(
  file=paste(path, "grp2.5-4f.eps", sep=""), width = 9, height = 9, pointsize = 24,
  horizontal = FALSE, onefile = FALSE, paper = "special",
  family="Palatino"
)
par(mar=c(3.2, 0.5, 1.5, 0.5), mgp=c(2.0, 0.7, 0))
par(bty="n")
plot(
  S, y, xlim = c(0, 1), ylim = c(0, max(z)),
  type = "l", col = "#E64B6B",
  xlab = expression(theta), ylab = NA,
  yaxt = "n", lwd = 8, main = "prior density & likelihood"
)
par(new=T)
plot(
  S, z, xlim = c(0, 1), ylim = c(0, max(z)),
  type = "l", col = "#5ECD22",
  xlab = NA, ylab = NA, yaxt = "n", xaxt = "n",
  lwd = 8
)
par(new=T)
plot(
  S, w, xlim = c(0, 1), ylim = c(0, max(z)),
  type = "l", col = "#75B5E1",
  xlab = NA, ylab = NA, yaxt = "n", xaxt = "n",
  lwd = 8
)

legend(
  0, max(z),
  c("non-conjugate prior", expression(paste("beta prior (", alpha + beta, " = 5)", sep="")), "likelihood"),
  col = c("#E64B6B", "#75B5E1", "#5ECD22"),
  lty = c(1, 1, 1), lwd = c(8, 8, 8), merge = TRUE, bty = "n", cex  = 0.8
)

dev.off()

#sd(sample(S, 10000, replace=TRUE, prob=y))
#sd(sample(S, 10000, replace=TRUE, prob=w))
#sd(sample(S, 10000, replace=TRUE, prob=z))
