path <- commandArgs()[6]


##############################
load(paste(path, "gd80to84.RData", sep=""))
load(paste(path, "gd85to89.RData", sep=""))

gd80to84 <- gd80to84[!is.na(gd80to84$county), ]
gd85to89 <- gd85to89[!is.na(gd85to89$county), ]
gd85to89$state[gd85to89$state == "Alaska"] <- "ALASKA"
gd85to89$state[gd85to89$state == "IDADO"] <- "IDAHO"
gd80to84$county[gd80to84$county == "BRECKENRIDGE"] <- "BRECKINRIDGE"
gd80to84$county[gd80to84$county == "HAKON"] <- "HAAKON"
dat8089 <- merge(
  gd80to84, gd85to89, all = TRUE, by = c("state", "county"),
  suffixes = c(".8084", ".8589")
)

goodat <- dat8089[dat8089$good.8589 == 1, ]
goodat$dc <- goodat$dc.8084 + goodat$dc.8589
goodat$aadc <- goodat$aadc.8084 + goodat$aadc.8589
goodat$dcC <- goodat$dcC.8084 + goodat$dcC.8589
goodat$pop.8084 <- as.numeric(goodat$pop.8084)
goodat$pop.8589 <- as.numeric(goodat$pop.8589)
goodat$pop <- goodat$pop.8084 + goodat$pop.8589
goodat$dc <- as.numeric(goodat$dc)
goodat$pop1 <- (goodat$pop.8589 * goodat$dc)/goodat$aadc
goodat$pop1[goodat$dc == 0] <- 0

# save(goodat, file = paste(path, "goodat.RData",  sep=""))


##############################
postscript(
  file=paste(path, "grp2.8-3.eps", sep=""), width = 9, height = 9, pointsize = 24,
  horizontal = FALSE, onefile = FALSE, paper = "special",
  family="Palatino"
)
par(mar=c(3.2, 3.2, 0.5, 0.5), mgp=c(2.0, 0.7, 0))
par(bty="l")
plot(
  goodat$pop / 10^6, goodat$dc  / (goodat$pop / 10^5),
  pch = 20, col = "#E64B6B",
  xlab = "population (millions)",
  ylab = "raw death rate (per 100,000)"
)
dev.off()


##############################
postscript(
  file=paste(path, "grp2.8-4.eps", sep=""), width = 9, height = 9, pointsize = 24,
  horizontal = FALSE, onefile = FALSE, paper = "special",
  family="Palatino"
)
par(mar=c(3.2, 3.2, 0.5, 0.5), mgp=c(2.0, 0.7, 0))
par(bty="l")
plot(
  log10(goodat$pop), goodat$dc  / (goodat$pop / 10^5),
  pch = 20, col = "#E64B6B",
  xlab = "log10 (population)",
  ylab = "raw death rate (per 100,000)"
)
dev.off()



##############################
postscript(
  file=paste(path, "grp2.8-5.eps", sep=""), width = 9, height = 9, pointsize = 24,
  horizontal = FALSE, onefile = FALSE, paper = "special",
  family="Palatino"
)
par(mar=c(3.2, 3.2, 0.5, 0.5), mgp=c(2.0, 0.7, 0))
par(bty="l")
plot(
  log10(goodat$pop), (goodat$dc + 20) / ((430000 + goodat$pop) / 10^5),
  pch = 20, col = "#E64B6B",
  xlab = "log10 (population)",
  ylab = "posterior death rate (per 100,000)"
)
dev.off()


##############################
set.seed(0414)

interval <- data.frame(
  pop= goodat$pop,
  q1 = qgamma(0.25, 20 + goodat$dc, 430000 + goodat$pop),
  med= qgamma(0.50, 20 + goodat$dc, 430000 + goodat$pop),
  q3=  qgamma(0.75, 20 + goodat$dc, 430000 + goodat$pop)
)
x <- sample(1:3067, 100)
interval <- interval[x,,]

postscript(
  file=paste(path, "grp2.8-6.eps", sep=""), width = 9, height = 9, pointsize = 24,
  horizontal = FALSE, onefile = FALSE, paper = "special",
  family="Palatino"
)
par(mar=c(3.2, 3.2, 0.5, 0.5), mgp=c(2.0, 0.7, 0))
par(bty="l")
plot(
  log10(interval$pop), 10^5 * interval$med,
  pch = 20, col = "#E64B6B", ylim = c(2, 8),
  xlab = "log10 (population)",
  ylab = "posterior death rate (per 100,000)"
)
segments(
  log10(interval$pop), 10^5 * interval$q1,
  log10(interval$pop), 10^5 * interval$q3,
  col = "#E64B6B", lwd = 2
)
dev.off()


##############################
points <- seq(0, 0.00035, 0.0000003)
postscript(
  file=paste(path, "grp2.8-7.eps", sep=""), width = 16, height = 9, pointsize = 24,
  horizontal = FALSE, onefile = FALSE, paper = "special",
  family="Palatino"
)
par(mar=c(3.2, 3.2, 0.5, 0.5), mgp=c(2.0, 0.7, 0))
par(bty="l")
hist(
  goodat$dc / goodat$pop, breaks=150, probability=T,
  xlab = expression(theta), ylab="density", main = "",
  col = "#E64B6B", border = "white"
)
lines(
  points,
  dgamma(points, shape=20, rate=430000),
  col="#92D78F", lwd=6
)
lines(
  points,
  dgamma(points, shape=5, rate=84000),
  col="#75B5E1", lwd=6
)
legend(
  0.00025, 40000, c("Gamma(5, 84000)", "Gamma(20, 430000)"),
  lty=c(1, 1), col = c("#75B5E1", "#92D78F"), 
  lwd=c(6, 6), merge = TRUE
)
dev.off()
